package Stopword::Pod;
use strict;
use warnings;

sub foo {}

1;

__END__

=head1 NAME

Stopword::Pod - correctly spelled POD and a Xzaue creator

=END

